
#ifndef KIDENTITYMANAGEMENTWIDGETS_EXPORT_H
#define KIDENTITYMANAGEMENTWIDGETS_EXPORT_H

#ifdef KIDENTITYMANAGEMENTWIDGETS_STATIC_DEFINE
#  define KIDENTITYMANAGEMENTWIDGETS_EXPORT
#  define KIDENTITYMANAGEMENTWIDGETS_NO_EXPORT
#else
#  ifndef KIDENTITYMANAGEMENTWIDGETS_EXPORT
#    ifdef KPim6IdentityManagementWidgets_EXPORTS
        /* We are building this library */
#      define KIDENTITYMANAGEMENTWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIDENTITYMANAGEMENTWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIDENTITYMANAGEMENTWIDGETS_NO_EXPORT
#    define KIDENTITYMANAGEMENTWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIDENTITYMANAGEMENTWIDGETS_DEPRECATED
#  define KIDENTITYMANAGEMENTWIDGETS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIDENTITYMANAGEMENTWIDGETS_DEPRECATED_EXPORT
#  define KIDENTITYMANAGEMENTWIDGETS_DEPRECATED_EXPORT KIDENTITYMANAGEMENTWIDGETS_EXPORT KIDENTITYMANAGEMENTWIDGETS_DEPRECATED
#endif

#ifndef KIDENTITYMANAGEMENTWIDGETS_DEPRECATED_NO_EXPORT
#  define KIDENTITYMANAGEMENTWIDGETS_DEPRECATED_NO_EXPORT KIDENTITYMANAGEMENTWIDGETS_NO_EXPORT KIDENTITYMANAGEMENTWIDGETS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIDENTITYMANAGEMENTWIDGETS_NO_DEPRECATED
#    define KIDENTITYMANAGEMENTWIDGETS_NO_DEPRECATED
#  endif
#endif

#endif /* KIDENTITYMANAGEMENTWIDGETS_EXPORT_H */
